pub struct PointN<N>(pub N);Expand description
An N-dimensional point (where N=2 or N=3), which is usually just a primitive array like
[i32; 2] or [i32; 3]. It is most convenient to construct points of any dimension as:
use building_blocks_core::PointN;
let p2 = PointN([1, 2]); // 2D
let p3 = PointN([1, 2, 3]); // 3DPoints support basic linear algebraic operations such as addition, subtraction, scalar multiplication, and scalar division.
let p1 = PointN([1, 2]);
let p2 = PointN([3, 4]);
assert_eq!(p1 + p2, PointN([4, 6]));
assert_eq!(p1 - p2, PointN([-2, -2]));
assert_eq!(p1 * 2, PointN([2, 4]));
assert_eq!(p1 / 2, PointN([0, 1]));
// Also some component-wise operations.
assert_eq!(p1 * p2, PointN([3, 8]));
assert_eq!(p1 / p2, PointN([0, 0]));
assert_eq!(p2 / p1, PointN([3, 2]));There is also a partial order defined on points which says that a point A is greater than a point B if and only if all of the components of point A are greater than point B. This is useful for easily checking is a point is inside of the extent between two other points:
let min = PointN([0, 0, 0]);
let least_upper_bound = PointN([3, 3, 3]);
let p = PointN([0, 1, 2]);
assert!(min <= p && p < least_upper_bound);Tuple Fields
0: NImplementations
Sourceimpl PointN<[i32; 2]>
impl PointN<[i32; 2]>
pub const SQUARE_CORNER_OFFSETS: [Self; 4] = _
pub const VON_NEUMANN_OFFSETS: [Self; 4] = _
pub const MOORE_OFFSETS: [Self; 8] = _
Sourceimpl<T> PointN<[T; 3]>where
T: Copy,
impl<T> PointN<[T; 3]>where
T: Copy,
pub fn axis_component(self, axis: Axis3) -> T
pub fn x(self) -> T
pub fn y(self) -> T
pub fn z(self) -> T
pub fn xy(self) -> Point2<T>
pub fn yx(self) -> Point2<T>
pub fn yz(self) -> Point2<T>
pub fn zy(self) -> Point2<T>
pub fn zx(self) -> Point2<T>
pub fn xz(self) -> Point2<T>
pub fn yzx(self) -> Self
pub fn zxy(self) -> Self
pub fn zyx(self) -> Self
Sourceimpl PointN<[i32; 3]>
impl PointN<[i32; 3]>
pub const CUBE_CORNER_OFFSETS: [Self; 8] = _
pub const VON_NEUMANN_OFFSETS: [Self; 6] = _
pub const MOORE_OFFSETS: [Self; 26] = _